use crate::GP_CLIENT_LOCK_FILE;
use gpapi::GP_SERVICE_LOCK_FILE;
use log::{info, warn};
use std::{fs, str::FromStr, thread, time::Duration};
use sysinfo::{Pid, Signal, System};

pub(crate) struct DisconnectHandler;

impl DisconnectHandler {
  pub(crate) fn new() -> Self {
    Self
  }

  pub(crate) fn handle(&self) -> anyhow::Result<()> {
    if let Ok(c) = fs::read_to_string(GP_CLIENT_LOCK_FILE) {
      send_signal(c.trim(), Signal::Interrupt).unwrap_or_else(|err| {
        warn!("Failed to send signal to client: {}", err);
      });
    };

    if let Ok(c) = fs::read_to_string(GP_SERVICE_LOCK_FILE) {
      c.split(':').next().map_or_else(
        || info!("Failed to extract PID from: {}", c),
        |pid| {
          send_signal(pid, Signal::User1).unwrap_or_else(|err| {
            warn!("Failed to send signal to service: {}", err);
          });
        },
      );
    };

    // sleep for 3 seconds to give the client and service time to shut down
    thread::sleep(Duration::from_secs(3));

    Ok(())
  }
}

fn send_signal(pid: &str, signal: Signal) -> anyhow::Result<()> {
  let s = System::new_all();
  let pid = Pid::from_str(pid)?;

  if let Some(process) = s.process(pid) {
    info!("Found process {}, sending signal...", pid);

    if process.kill_with(signal).is_none() {
      warn!("Failed to kill process {}", pid);
    }
  }
  Ok(())
}
